@@ -6,7 +6,7 @@ from typing import List, Tuple
 
 from dataclasses import dataclass
 from typing import List, Optional
-from higgs.transformers.models.whisper.processing_whisper import WhisperProcessor
+from transformers.models.whisper.processing_whisper import WhisperProcessor
 
 from ..dataset.chatml_dataset import ChatMLDatasetSample
 from ..model.higgs_audio.utils import build_delay_pattern_mask
