@@ -1,4 +1,4 @@
-from higgs.transformers import AutoConfig, AutoModel
+from transformers import AutoConfig, AutoModel
 
 from .configuration_higgs_audio import HiggsAudioConfig, HiggsAudioEncoderConfig
 from .modeling_higgs_audio import HiggsAudioModel
