@@ -2,7 +2,7 @@ import contextlib
 from contextlib import contextmanager
 from functools import wraps
 import torch
-from higgs.transformers.integrations import is_deepspeed_available
+from transformers.integrations import is_deepspeed_available
 
 if is_deepspeed_available():
     from deepspeed.utils import groups as deepspeed_groups
