@@ -6,10 +6,10 @@ from io import BytesIO
 from dataclasses import dataclass
 from typing import List, Optional, Union
 from copy import deepcopy
-from higgs.transformers import AutoTokenizer, AutoProcessor
-from higgs.transformers.cache_utils import StaticCache
-from higgs.transformers.generation.streamers import BaseStreamer
-from higgs.transformers.generation.stopping_criteria import StoppingCriteria
+from transformers import AutoTokenizer, AutoProcessor
+from transformers.cache_utils import StaticCache
+from transformers.generation.streamers import BaseStreamer
+from transformers.generation.stopping_criteria import StoppingCriteria
 from dataclasses import asdict
 from loguru import logger
 import threading
